@@ -8,7 +8,7 @@ from chameleon.core.template import Macro
 
 class HTMLPageApi(SkinApi):
     """HTML-page helper."""
-    
+
     def __call__(self, name=None):
         if name is not None:
             htmlpage = get_htmlpage(self.context, self.request, name)
@@ -16,8 +16,8 @@ class HTMLPageApi(SkinApi):
             htmlpage = component.getMultiAdapter(
                 (self.context, self.request), IHTMLPage)
 
-        def render(**kwargs):
+        def render(slots, **kwargs):
             return htmlpage.template.render_macro(
-                "", global_scope=False, parameters=kwargs)
-        
+                "", global_scope=False, slots=slots, parameters=kwargs)
+
         return Macro(render)
